@@ -2,5 +2,4 @@
 void F77_NAME(mvtdst)(int *n, int *nu, double *lower, double *upper,
                       int *infin, double *corr, double *delta,
                       int *maxpts, double *abseps, double *releps,
-                      double *tol, double *error, double *value,
-                      int *inform);
+                      double *error, double *value, int *inform);
